@@ -7,7 +7,7 @@ use boolean qw(true false);
 
 our ($VERSION, @EXPORT_OK);
 
-$VERSION = '0.06';
+$VERSION = '0.08';
 @EXPORT_OK = qw(trim);
 
 sub _valid_date
@@ -38,6 +38,8 @@ sub _valid
     my $opts = pop;
     my %values = @_;
 
+    delete $values{nanosecond}; # always valid
+
     my %set = map { $_ => $self->{datetime}->$_ } @{$opts->{units}};
 
     while (my ($unit, $value) = each %values) {
@@ -92,7 +94,7 @@ __END__
 
 =head1 NAME
 
-DateTime::Format::Natural::Utils - Handy utility methods
+DateTime::Format::Natural::Utils - Handy utility functions/methods
 
 =head1 SYNOPSIS
 
@@ -100,7 +102,7 @@ DateTime::Format::Natural::Utils - Handy utility methods
 
 =head1 DESCRIPTION
 
-The C<DateTime::Format::Natural::Utils> class consists of utility methods.
+The C<DateTime::Format::Natural::Utils> class consists of utility functions/methods.
 
 =head1 SEE ALSO
 
